
# Type: deprecated element has exact replacement


When an element is deprecated, it can be automatically replaced by this uri or curie

URI: [meta:deprecated_element_has_exact_replacement](https://w3id.org/biolink/biolinkml/meta/deprecated_element_has_exact_replacement)


## Domain and Range

None ->  <sub>OPT</sub> [Uriorcurie](types/Uriorcurie.md)

## Parents


## Children


## Used by

 * [ClassDefinition](ClassDefinition.md)
 * [Definition](Definition.md)
 * [Element](Element.md)
 * [SchemaDefinition](SchemaDefinition.md)
 * [SlotDefinition](SlotDefinition.md)
 * [SubsetDefinition](SubsetDefinition.md)
 * [TypeDefinition](TypeDefinition.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | IAO:0100001 |

